@@ -5,14 +5,13 @@ from collections import namedtuple as NamedTuple
 import colorama
 colorama.init()
 
-from constants import ENCODING, SEPARATOR_WIDTH
-from constants import Enum, unique, auto
-from exporting import doctrim
-from naming import qualified_name
-from predicates import tuplize
-from typology import string_types, bytes_types
-from .enums import alias, AliasingEnumMeta
-from exporting import Exporter
+from clu.constants import ENCODING, SEPARATOR_WIDTH
+from clu.constants import Enum, unique, auto
+from clu.exporting import doctrim
+from clu.naming import qualified_name
+from clu.typology import string_types, bytes_types
+from clu.enums import alias, AliasingEnumMeta
+from clu.exporting import Exporter
 
 exporter = Exporter()
 export = exporter.decorator()
@@ -186,10 +185,7 @@ class Weight(ANSIBase, metaclass=ANSI, source=colorama.Style):
     RESET_ALL           = auto()
     RESET               = alias(RESET_ALL)
 
-ANSIFormatBase = NamedTuple('ANSIFormatBase', ('text', 'background', 'weight'),
-                                               defaults=tuplize(Background.NOTHING,
-                                                                    Weight.NORMAL),
-                                               module=__file__)
+ANSIFormatBase = NamedTuple('ANSIFormatBase', ('text', 'background', 'weight'), module=__file__)
 
 @export
 class ANSIFormat(ANSIFormatBase):
@@ -212,9 +208,8 @@ class ANSIFormat(ANSIFormatBase):
 
 @export
 def print_ansi(text, color=''):
-    """ Print text in ANSI color, using optional inline markup
-        from `colorama` for terminal color-escape delimiters
-    """
+    """ print_ansi(…) → Print text in ANSI color, using optional inline markup
+                        from `colorama` for terminal color-escape delimiters """
     fmt = ANSIFormat(color)
     for line in text.splitlines():
         print(fmt.render(line), sep='')
@@ -223,7 +218,8 @@ def print_ansi(text, color=''):
 def print_ansi_centered(text, color='',
                               filler='•',
                               width=SEPARATOR_WIDTH):
-    """ Print a string to the terminal, centered and bookended with asterisks """
+    """ print_ansi_centered(…) → Print a string to the terminal, centered
+                                 and bookended with asterisks """
     message = f" {text.strip()} "
     asterisks = int((width / 2) - (len(message) / 2))
     
@@ -244,7 +240,7 @@ def highlight(code_string, language='json',
     formatter = pygments.formatters.get_formatter_by_name(markup, style=style)
     return pygments.highlight(code_string, lexer=LexerCls(), formatter=formatter)
 
-export(print_separator,     name='print_separator', doc="print_separator(filler_char) → print filler_char TERMINAL_WIDTH times")
+export(print_separator,     name='print_separator', doc="print_separator(filler_char='-') → print filler_char TERMINAL_WIDTH times")
 
 # NO DOCS ALLOWED:
 export(Text)
