@@ -7,7 +7,50 @@ class TestPredicates(object):
     
     """ Run the tests for the clu.predicates module. """
     
-    def test_utility_helper_functions(self):
+    def test_utility_helpers_for_builtin_predicates(self):
+        from clu.predicates import allof, anyof, noneof
+        
+        all_OK = (True, True, True, True, True)
+        any_OK = (False, False, True, False, True)
+        non_OK = (False, False, False, False, False)
+        
+        # What we expect:
+        assert all(all_OK)
+        assert any(all_OK)
+        assert any(any_OK)
+        assert not any(non_OK)
+        assert not all(any_OK) # … but WHO CARES really;
+                               # notice, we don’t have a
+                               # “someof(…)” function or
+                               # anything like that dogg
+        
+        # The “real” tests:
+        assert allof(*all_OK)
+        assert anyof(*all_OK)
+        assert anyof(*any_OK)
+        assert noneof(*non_OK)
+        
+        assert allof(True, True, True, True, True)
+        assert anyof(True, True, True, True, True)
+        assert anyof(False, False, True, False, True)
+        assert noneof(False, False, False, False, False)
+        
+        assert allof(1, 2, 3, 4, 5)
+        assert allof([1], [2], [3], [4], [5])
+        assert anyof([], {}, tuple(), '', b'b')
+        assert anyof(0, 1, 2, 3, 4, 5)
+        
+        class Falsified(object):
+            
+            def __bool__(self):
+                return False
+        
+        assert not noneof(0, 1, 2, 3, 4, 5)
+        assert not noneof(1, 2, 3, 4, 5)
+        assert noneof([], {}, tuple(), '', b'')
+        assert noneof(0, None, False, Falsified())
+    
+    def test_utility_helpers_for_builtin_containers(self):
         """ » Checking “tuplize/uniquify/listify” functions from clu.predicates … """
         from clu.predicates import tuplize, uniquify, listify
         
@@ -348,7 +391,8 @@ class TestPredicates(object):
     
     def test_nops(self):
         """ » Checking “always/never/nuhuh/no_op” lambdas from clu.predicates … """
-        from clu.predicates import (always, never, nuhuh,
+        from clu.predicates import (negate, 
+                                    always, never, nuhuh,
                                     no_op, predicate_nop,
                                             function_nop)
         
@@ -358,6 +402,9 @@ class TestPredicates(object):
             assert always(single) is True
             assert never(single) is False
             assert nuhuh(single) is None
+            assert negate(always)(single) is False
+            assert negate(never)(single) is True
+            assert negate(nuhuh)(single) is True # not not None is True
             assert no_op(single, 'get') is single
             assert predicate_nop(*singles) is None
             assert function_nop(single) is None
@@ -444,8 +491,14 @@ class TestPredicates(object):
     
     def test_hasattr_shortcuts(self):
         """ » Checking “hasattr/haspyattr” shortcuts from clu.predicates … """
-        from clu.predicates import (haspyattr, anyattrs, allattrs,
-                                               anypyattrs, allpyattrs)
+        from clu.predicates import (noattr, haspyattr, nopyattr,
+                                    anyattrs, allattrs, noattrs,
+                                    anypyattrs, allpyattrs, nopyattrs)
+        
+        assert noattr(object, 'base')
+        assert noattr(object, 'class')
+        assert not noattr(object, 'mro')
+        
         assert not hasattr(object, 'base')
         assert not hasattr(object, 'class')
         assert hasattr(object, 'mro')
@@ -457,14 +510,26 @@ class TestPredicates(object):
         assert not haspyattr(object, 'dogg')
         assert not haspyattr(object, 'wtf')
         
+        assert not nopyattr(object, 'base')
+        assert not nopyattr(object, 'class')
+        assert not nopyattr(object, 'mro')
+        assert nopyattr(object, 'yo')
+        assert nopyattr(object, 'dogg')
+        assert nopyattr(object, 'wtf')
+        
         assert anyattrs(object, 'base', 'class', 'mro')
         assert not allattrs(object, 'base', 'class', 'mro')
         assert not anyattrs(object, 'yo', 'dogg', 'i', 'have', 'not', 'heard')
         assert allattrs(object, '__base__', '__class__', '__mro__')
+        assert noattrs(object, 'yo', 'dogg', 'i', 'have', 'not', 'heard')
+        assert not noattrs(object, 'base', 'class', 'mro')
         
         assert anypyattrs(object, 'yo', 'dogg', 'mro')
         assert not allpyattrs(object, 'yo', 'dogg', 'mro')
         assert not anypyattrs(object, 'yo', 'dogg', 'wtf')
+        assert nopyattrs(object, 'yo', 'dogg', 'wtf')
+        assert not nopyattrs(object, 'yo', 'dogg', 'mro')
+        
         assert allpyattrs(object, 'base', 'class', 'mro',
                                   'call', 'dict', 'doc',
                                   'name', 'hash', 'dir')
@@ -493,7 +558,7 @@ class TestPredicates(object):
     
     def test_attr_accessor(self):
         """ » Checking “attr(•) accessor from clu.predicates …” """
-        from clu.predicates import attr
+        from clu.predicates import attr, uncallable
         
         # plistlib on Python 2.x uses those ungainly `writePlistToString`
         # methods; on Python 3.x you have the more reasonable and expected
@@ -503,11 +568,20 @@ class TestPredicates(object):
         load = attr(plistlib, 'loads', 'readPlistFromString')
         assert dump is not None
         assert load is not None
+        assert callable(dump)
+        assert callable(load)
         
         # When attr(…) can't find an attribute matching any of the names
         # provided, you get None back:
         wat = attr(plistlib, 'yo_dogg', 'wtf_hax')
         assert wat is None
+        assert uncallable(wat)
+        
+        # … Unless of course a “default” value was specified:
+        jon_snow = object() # it’s a sentinel GET IT?!?
+        hax = attr(plistlib, 'yo_dogg', 'wtf_hax', default=jon_snow)
+        assert hax is jon_snow
+        assert uncallable(hax)
     
     def test_boolean_predicates(self):
         """ » Checking basic isXXX(•) functions from clu.typology … """
@@ -523,10 +597,11 @@ class TestPredicates(object):
         
         assert graceful_issubclass(int, int)
         
-        assert ispathtype(str)
-        assert ispathtype(bytes)
         if hasattr(os, 'PathLike'):
             assert ispathtype(os.PathLike)
+        
+        assert ispathtype(str)
+        assert ispathtype(bytes)
         assert not ispathtype(SimpleNamespace)
         assert ispath('/yo/dogg')
         assert not ispath(SimpleNamespace())
@@ -555,11 +630,10 @@ class TestPredicates(object):
         
         assert islambda(lambda: None)
         assert islambda(attr)
-        # assert not islambda(export)
         assert islambda(graceful_issubclass) # IT IS NOW DOGG
+        
         assert isfunction(lambda: None)
         assert isfunction(attr)
-        # assert isfunction(export)
         assert isfunction(graceful_issubclass)
         assert not isfunction(SimpleNamespace())
         assert isfunction(SimpleNamespace) # classes are callable!
